<?php

namespace Teknisa\TCO\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;

class Tco01010RevisaoReceita extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $environment;
    protected $entityManager;
    protected $dataSourceToSave;
    protected $Tco01010RevisaoReceitaService;
    protected $newCode;
    protected $dataSourceName;
    protected $recepadr = "recepadr";
    protected $recefili = "recefili";
    protected $receregiao = "receregiao";
    protected $recepadquali = "recepadquali";
    protected $receserv = "receserv";
    protected $recepratcardtrab = "recepratcardtrab";

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $dataSourceManager, $Tco01010RevisaoReceitaService, $newCode) {
        $this->crudService   = $crudService;
        $this->environment   = $environment;
        $this->entityManager = $entityManager;
        $this->dataSourceManager = $dataSourceManager;
        $this->Tco01010RevisaoReceitaService = $Tco01010RevisaoReceitaService;
        $this->newCode = $newCode;
    }
    
    public function saveProducts(DTO\Request $request, DTO\Response $response) {
        try {
            $conn = $this->entityManager->getConnection();
            $conn->beginTransaction();
            $dataSet = $request->getDataSet();
            $row = $dataSet->getRows()[0];
            $dataSet = $this->getRowIdentity($dataSet);
            $dataSet = $this->crudService->getRowsToSave($request, $this->dataSourceToSave);
            $this->crudService->save($this->dataSourceToSave, $dataSet);
            $this->Tco01010RevisaoReceitaService->atualizaCustoProdutoProposta($row);
            $response->addDataSet(new DataSet($this->dataSourceToSave, $dataSet));
            $conn->commit();
        } catch (\Exception $e) {
            $conn->rollback();
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    
    private function getRowIdentity($dataSet){
        $row = $dataSet->getRows()[0];
        $qtBruta = (float) $row['QTDBRUTA'];
        $qtPerda = ((float) $row['VRPERDALIMPEZA'])/100 * $qtBruta;
        $qtCalcNutr = round($qtBruta - $qtPerda, 5);
        if($row["TIPORECE"] == "P"){
            // Padrão  
            $this->dataSourceToSave = "recepadr";
            $row['QTPRODPRAT']   = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCPR'] = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORPR'] = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTAPRUNR'] = (float) $row['QTDBRUTA'];
            $row['NRORG']        = $this->environment->getNrOrg();
            $row['QTUNIDESTPR'] = $qtBruta;
            $row['QTBRUTAPR'] = $qtBruta;
            $row['VRPEFATNUTPR'] = 100;
            $row['VRPERCDEGELO'] = 0;
            $row['QTCALCNUTRPR'] = $qtCalcNutr;
            $row['QTCOMPLPRODPADR'] = 0;
        } else if($row["TIPORECE"] == "F"){
            // Local
            $this->dataSourceToSave = "recefili";
            $row['QTPRODRECLOC'] = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCLO'] = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORLO'] = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTALOUNR'] = (float) $row['QTDBRUTA'];
            $row['CDFILIAL']     = $this->Tco01010RevisaoReceitaService->getFilialParamTco();
            $row['NRORG']        = $this->environment->getNrOrg();
            $row['QTUNIDESTLO'] = $qtBruta;
            $row['QTBRUTALO'] = $qtBruta;
            $row['VRPEFATNUTLO'] = 100;
            $row['VRPERCDEGELO'] = 0;
            $row['QTCALCNUTRLO'] = $qtCalcNutr;
            $row['QTCOMPLPRODFILI'] = 0;
        } else if($row["TIPORECE"] == "Q"){
            // Padrão de Qualidade
            $this->dataSourceToSave = "recepadquali";
            $row['QTPRODRECPADQ']   = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCPADQ']  = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORPADQ']  = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTAPADQUNR']  = (float) $row['QTDBRUTA'];
            $row['NRORG']           = $this->environment->getNrOrg();
            $row['NRRECEPADQUALI']  = empty($row["NRRECEPADQUALI"]) ? $this->newCode->getCodeByTableName('RECEPADQUALI', $row['NRORG']) : $row["NRRECEPADQUALI"];
        } else if($row["TIPORECE"] == "R"){
            // Região
            $this->dataSourceToSave = "receregiao";
            $row['QTPRODRECREGIAO']  = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCREGIAO'] = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORREGIAO'] = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTAREGIAOUNR'] = (float) $row['QTDBRUTA'];
            $row['NRORG']            = $this->environment->getNrOrg();
            $row["NRRECEREGIAO"]     = empty($row["NRRECEREGIAO"]) ? $this->newCode->getCodeByTableName('RECEREGIAO', $row['NRORG']) : $row["NRRECEREGIAO"];
        } else if($row["TIPORECE"] == "S"){
            // Serviço
            $this->dataSourceToSave = "receserv"; 
            $row['QTPRODRECSER'] = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCSE'] = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORSE'] = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTASEUNR'] = (float) $row['QTDBRUTA'];
            $row['CDSERVFILI']   = $row['CDSERVFILI'];
            $row['CDFILIAL']     = $this->Tco01010RevisaoReceitaService->getFilialParamTco();
            $row['NRORG']        = $this->environment->getNrOrg();
            $row['QTUNIDESTSE'] = $qtBruta;
            $row['QTBRUTASE'] = $qtBruta;
            $row['VRPEFATNUTSE'] = 100;
            $row['VRPERCDEGELO'] = 0;
            $row['QTCALCNUTRSE'] = $qtCalcNutr;
            $row['QTCOMPLPRODSERV'] = 0;
        } else if($row["TIPORECE"] == "C"){
            // Cardapio da Proposta
            $this->dataSourceToSave    = "recepratcardtrab";
            $row['QTPRODRECCARDTRAB']  = (float) $row['QTPRODUTO'];
            $row['VRPEFATCOCCARDTRAB'] = (float) $row['VRGANHOCOCCAO'];
            $row['VRPEFATCORCARDTRAB'] = (float) $row['VRPERDALIMPEZA'];
            $row['QTBRUTACARDTRABUNR'] = (float) $row['QTDBRUTA'];
            $row['IDINCLUIDO'] = (isset($row['IDINCLUIDO'])) ? $row['IDINCLUIDO'] : 'N';
            $row['NRORG']              = $this->environment->getNrOrg();
            $row["NRRECEPRATCARDTRAB"] = empty($row["NRRECEPRATCARDTRAB"]) ? $this->newCode->getCodeByTableName('RECEPRATCARDTRAB', $row['NRORG']) : $row["NRRECEPRATCARDTRAB"];
        }
        return $dataSet;
    }
    
    public function getValuesStripe(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $row = $this->Tco01010RevisaoReceitaService->getFilialRece($row);
            $row = $this->Tco01010RevisaoReceitaService->getServicoRece($row);
            if(!empty($row['CDREGIAO']))
                $row = $this->Tco01010RevisaoReceitaService->getRegiaoRece($row);
            if(!empty($row['NRPADRAOQUALIDADE']))
                $row = $this->Tco01010RevisaoReceitaService->getPadQuaRece($row);
            $row = $this->Tco01010RevisaoReceitaService->getReceUtil($row);
            $row = $this->Tco01010RevisaoReceitaService->getParamplaneja($row);
            $response->addDataSet(new DataSet('valuesStripe', array($row)));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function replicaReceitas($request, $response){
        $row = $request->getRow();
        
        $conditions = [
            array(
                "columnName" => "CDPRATO",
                "operator"   => '=',
                "value"      => $row['CDPRATO']
            ),
            array(
                "columnName" => "CDFILAUXPRAT",
                "operator"   => '=',
                "value"      => $row['CDFILAUXPRAT']
            ),
            array(
                "columnName" => "CDREGIAO",
                "operator"   => '=',
                "value"      => $row['CDREGIAO_ORIGEM']
            ),
            array(
                "columnName" => "NRPADRAOQUALIDADE",
                "operator"   => '=',
                "value"      => $row['NRPADRAOQUALIDADE']
            )
        ];
        $receitas = $this->crudService->getFilteredDataSet('receregiao', $conditions);
        $receitas = $receitas->getRows();
        try{
            $this->entityManager->beginTransaction();
            foreach ($row['REGIOES_DESTINO'] as $regiao) {
                $this->Tco01010RevisaoReceitaService->deleteReceRegiao($row, $regiao);
            }
            foreach ($receitas as $receita) {
                $receita['CDOPERULTATU'] = $this->environment->getCdOperador();
                $receita['__is_new'] = true;
                $receita['changed'] = true;
                foreach ($row['REGIOES_DESTINO'] as $regiao) {
                    $receita['NRRECEREGIAO'] = $this->newCode->getCodeByTableName('RECEREGIAO', $receita['NRORG']);
                    $receita['CDREGIAO'] = $regiao;
                    $data = new DataSet('receregiao',array($receita));
                    $newRequest = new DTO\Request\DataSet($data, '', '', '');
                    $dataSet = $this->crudService->getRowsToSave($newRequest, 'receregiao');
                    $this->crudService->save('receregiao', $dataSet);
                }
            }
            $this->entityManager->commit();
        }catch(\Exception $e){
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function importarReceitaTCO($request, $response){
        $row = $request->getRow();
        $tpImportacao   = $row['TIPO_IMPORT'];
        $receitaOrigem  = $row['ORIGEM']['TIPO'];
        $receitaDestino = $row['DESTINO']['TIPO']; 
        switch ($receitaDestino) {
            case 'R':
                $dataSourceDestino = 'receregiao';
                $dadosPratoDestino = 'pratregiao';
            break;
            case 'Q':
                $dataSourceDestino = 'recepadquali';
                $dadosPratoDestino = 'pratpadquali';
            break;
            case 'P':
                $dataSourceDestino = 'recepadr';
                $dadosPratoDestino = 'pratpadr';
            break;
            case 'S':
                $dataSourceDestino = 'receserv';
                $dadosPratoDestino = 'pratserv';
            break;
            case 'F':
                $dataSourceDestino = 'recefili';
                $dadosPratoDestino = 'pratfili';
            break;
            case 'C':
                $dataSourceDestino = 'recepratcardtrab';
                $dadosPratoDestino = null;
            break;
        }
        
        switch ($receitaOrigem) {
            case 'R':
                $dataSourceOrigem = 'receregiao';
                $dadosPratoOrigem = 'pratregiao';
            break;
            case 'Q':
                $dataSourceOrigem = 'recepadquali';
                $dadosPratoOrigem = 'pratpadquali';
            break;
            case 'P':
                $dataSourceOrigem = 'recepadr';
                $dadosPratoOrigem = 'pratpadr';
            break;
            case 'S':
                $dataSourceOrigem = 'receserv';
                $dadosPratoOrigem = 'pratserv';
            break;
            case 'F':
                $dataSourceOrigem = 'recefili';
                $dadosPratoOrigem = 'pratfili';
            break;
            case 'C':
                $dataSourceOrigem = 'recepratcardtrab';
            break;
        }
        
        try{
            $this->entityManager->beginTransaction();
            // BUSCA RECEITA DE DESTINO
            $conditions = array(
                array(
                    "columnName" => "CDPRATO",
                    "operator" => "=",
                    "value" => $row['DESTINO']['CDPRATO']
                ),
                array(
                    "columnName" => "CDFILAUXPRAT",
                    "operator" => "=",
                    "value" => $row['DESTINO']['CDFILAUXPRAT']
                ),
                array(
                    "columnName" => "NRORG",
                    "operator" => "=",
                    "value" => $this->environment->getNrOrgTrab()
                )
            );
            if($receitaDestino == 'F' || $receitaDestino == 'S'){
                if($receitaDestino == 'S'){
                    array_push($conditions, 
                        array(
                            "columnName" => "CDSERVFILI",
                            "operator" => "=",
                            "value" => $row['DESTINO']['CDSERVFILI']
                        )
                    );
                }
                array_push($conditions, 
                    array(
                        "columnName" => "CDFILIAL",
                        "operator" => "=",
                        "value" => $row['DESTINO']['CDFILIAL']
                    )
                );
            }
            if($receitaDestino === 'C'){
                array_push($conditions, 
                    array(
                        "columnName" => "NRCARDAPIOTRAB",
                        "operator" => "=",
                        "value" => $row['DESTINO']['NRCARDAPIOTRAB']
                    )
                );
            }
            if($receitaDestino == 'R' || $receitaDestino == 'Q'){
                if($receitaDestino == 'R'){
                    array_push($conditions, 
                        array(
                            "columnName" => "CDREGIAO",
                            "operator" => "=",
                            "value" => $row['DESTINO']['CDREGIAO']
                        )
                    );
                }
                array_push($conditions, 
                    array(
                        "columnName" => "NRPADRAOQUALIDADE",
                        "operator" => "=",
                        "value" => $row['DESTINO']['NRPADRAOQUALIDADE']
                    )
                );
            }
            
            $filterCriteria = new \Zeedhi\Framework\DataSource\FilterCriteria($dataSourceDestino, $conditions);
            $dataSetProdRecD = $this->dataSourceManager->findBy($filterCriteria);
            $prodRec_D = $dataSetProdRecD->getRows();
            

            // BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
            if(!empty($dadosPratoDestino)){
                $filterCriteria = new \Zeedhi\Framework\DataSource\FilterCriteria($dadosPratoDestino, $conditions);
                $dataSet = $this->dataSourceManager->findBy($filterCriteria);
                
                
                $this->dataSourceManager->delete($dataSet);
            }
            
            
            // BUSCA A RECEITA DE ORIGEM, QUE SERÁ COPIADA
            if($receitaOrigem != 'C'){
                $conditions = array(
                    array(
                        "columnName" => "CDPRATO",
                        "operator" => "=",
                        "value" => $row['ORIGEM']['CDPRATO']
                    ),
                    array(
                        "columnName" => "CDFILAUXPRAT",
                        "operator" => "=",
                        "value" => $row['ORIGEM']['CDFILAUXPRAT']
                    ),
                    array(
                        "columnName" => "NRORG",
                        "operator" => "=",
                        "value" => $this->environment->getNrOrgTrab()
                    )
                );
                if($receitaOrigem == 'F' || $receitaOrigem == 'S'){
                    if($receitaOrigem == 'S'){
                        array_push($conditions, 
                            array(
                                "columnName" => "CDSERVFILI",
                                "operator" => "=",
                                "value" => $row['ORIGEM']['CDSERVFILI']
                            )
                        );
                    }
                    array_push($conditions, 
                        array(
                            "columnName" => "CDFILIAL",
                            "operator" => "=",
                            "value" => $row['ORIGEM']['CDFILIAL']
                        )
                    );
                }
                if($receitaOrigem == 'R' || $receitaOrigem == 'Q'){
                    if($receitaOrigem == 'R'){
                        array_push($conditions, 
                            array(
                                "columnName" => "CDREGIAO",
                                "operator" => "=",
                                "value" => $row['ORIGEM']['CDREGIAO']
                            )
                        );
                    }
                    array_push($conditions, 
                        array(
                            "columnName" => "NRPADRAOQUALIDADE",
                            "operator" => "=",
                            "value" => $row['ORIGEM']['NRPADRAOQUALIDADE']
                        )
                    );
                }
                
                $filterCriteria = new \Zeedhi\Framework\DataSource\FilterCriteria($dadosPratoOrigem, $conditions);
                $dataSet = $this->dataSourceManager->findBy($filterCriteria);
                $dadosPratoOrigem = $dataSet->getRows();
            }else{
                $dadosPratoOrigem = null;
            }
            
            if ($tpImportacao === 'A') { // ACRESCENTA
                if ($prodRec_D) {
                    foreach ($row['ROWS'] as $indice => $prodO) {
                        foreach ($prodRec_D as $prodD) {
                            if ($prodO['CDPRODUTO'] === $prodD['CDPRODUTO']) {
                                unset($row['ROWS'][$indice]);
                                continue 1;
                            }
                        }
                    }
                }
            } else { // SOBREPOE
                $this->dataSourceManager->delete($dataSetProdRecD);
            }
            
            foreach ($row['ROWS'] as $produto) {
                $code = $this->newCode->getCodeByTableName(strtoupper($dataSourceDestino), $this->environment->getNrOrgTrab());
                $produto['CODE']              = $code;
                $produto['CDFILIAL']          = $row['DESTINO']['CDFILIAL'];
                $produto['CDSERVFILI']        = $row['DESTINO']['CDSERVFILI'];
                $produto['CDPRATO']           = $row['DESTINO']['CDPRATO'];
                $produto['CDFILAUXPRAT']      = $row['DESTINO']['CDFILAUXPRAT'];
                $produto['NRPADRAOQUALIDADE'] = $row['DESTINO']['NRPADRAOQUALIDADE'];
                $produto['CDREGIAO']          = $row['DESTINO']['CDREGIAO'];
                $this->insereReceita($produto, $dataSourceDestino);
            }
            if ($dadosPratoOrigem && !empty($dadosPratoDestino)){
                $dadosPratoOrigem = $dadosPratoOrigem[0];
                switch ($receitaOrigem) {
                    case 'R':
                        $dadosPratoOrigem['COR'] = $dadosPratoOrigem['NRCORPRIREGIAO'];
                        $dadosPratoOrigem['QUANTIDADE'] = $dadosPratoOrigem['QTPADRAOREGIAO'];
                    break;
                    case 'Q':
                        $dadosPratoOrigem['COR'] = $dadosPratoOrigem['NRCORPRIPADQ'];
                        $dadosPratoOrigem['QUANTIDADE'] = $dadosPratoOrigem['QTPADRAOPADQ'];
                    break;
                    case 'P':
                        $dadosPratoOrigem['COR'] = $dadosPratoOrigem['NRCORPRIPRAT'];
                        $dadosPratoOrigem['QUANTIDADE'] = $dadosPratoOrigem['QTPADRAOPRAT'];
                    break;
                    case 'S':
                        $dadosPratoOrigem['COR'] = $dadosPratoOrigem['NRCORPRISERV'];
                        $dadosPratoOrigem['QUANTIDADE'] = $dadosPratoOrigem['QTPADRAOSERV'];
                    break;
                    case 'F':
                        $dadosPratoOrigem['COR'] = $dadosPratoOrigem['NRCORPRIFILI'];
                        $dadosPratoOrigem['QUANTIDADE'] = $dadosPratoOrigem['QTPADRAOFILI'];
                    break;
                }
                
                $code = $this->newCode->getCodeByTableName(strtoupper($dadosPratoDestino), $this->environment->getNrOrgTrab());
                $dadosPratoOrigem['CODE']              = $code;
                $dadosPratoOrigem['CDFILIAL']          = $row['DESTINO']['CDFILIAL'];
                $dadosPratoOrigem['CDSERVFILI']        = $row['DESTINO']['CDSERVFILI'];
                $dadosPratoOrigem['CDPRATO']           = $row['DESTINO']['CDPRATO'];
                $dadosPratoOrigem['CDFILAUXPRAT']      = $row['DESTINO']['CDFILAUXPRAT'];
                $dadosPratoOrigem['NRPADRAOQUALIDADE'] = $row['DESTINO']['NRPADRAOQUALIDADE'];
                $dadosPratoOrigem['CDREGIAO']          = $row['DESTINO']['CDREGIAO'];
                $this->insereDadosPrato($dadosPratoOrigem, $dadosPratoDestino);
            }
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function insereReceita($produto, $dataSourceDestino){
        $qtLiq = (float) $produto['QUANTIDADE'];
        $ganho = (float) $produto['GANHOCOC'];
        $perda = (float) $produto['PERDALIMP'];
        $qtBruta = $qtLiq/(1 + ($ganho/100));
        if ($perda < 100) {
            $qtBruta = $qtBruta/(1 - ($perda/100));
        }
        $qtPerda = $perda/100 * $qtBruta;
        $qtCalcNutr = round($qtBruta - $qtPerda, 5);
        
        switch ($dataSourceDestino) {
            case 'recepadr':
                $dadosReceitaInserir = array(
                    'NRORG'           => $produto['NRORG'],
                    '__is_new'        => true,
                    'CDFILAUXPRAT'    => $produto['CDFILAUXPRAT'],
                    'CDPRATO'         => $produto['CDPRATO'],
                    'CDPRODUTO'       => $produto['CDPRODUTO'],
                    'SGUNIDADE'       => $produto['SGUNIDADEPROD'],
                    'QTPRODPRAT'      => $produto['QUANTIDADE'],
                    'VRPEFATCOCPR'    => $produto['GANHOCOC'],
                    'VRPEFATCORPR'    => $produto['PERDALIMP'],
                    'QTBRUTAPR'       => $qtBruta,
                    'QTUNIDESTPR'     => $qtBruta,
                    'VRPEFATNUTPR'    => '100',
                    'QTCALCNUTRPR'    => $qtCalcNutr,
                    'QTBRUTAPRUNR'    => $qtBruta,
                    'HRTEMPPREPPR'    => '00000',
                    'IDPRODBASEPR'    => 'N',
                    'IDQTDEFIXPR'     => 'N',
                    'IDUTCOMPENTDIRP' => 'N',
                    'QTCOMPLPRODPADR' => '0',
                    'IDTPREQPRODPADR' => 'P',
                    'CDAPRERECE'      => null,
                    'QTLIMSEGPADR'    => null,
                    'VRPERCDEGELO'    => 0
                );
            break;
            case 'receserv':
                $dadosReceitaInserir = array(
                    'NRORG'           => $produto['NRORG'],
                    '__is_new'        => true,
                    'CDFILAUXPRAT'    => $produto['CDFILAUXPRAT'],
                    'CDPRATO'         => $produto['CDPRATO'],
                    'CDFILIAL'        => $produto['CDFILIAL'],
                    'CDSERVFILI'      => $produto['CDSERVFILI'],
                    'CDPRODUTO'       => $produto['CDPRODUTO'],
                    'SGUNIDADE'       => $produto['SGUNIDADEPROD'],
                    'QTPRODRECSER'    => $produto['QUANTIDADE'],
                    'VRPEFATCOCSE'    => $produto['GANHOCOC'],
                    'VRPEFATCORSE'    => $produto['PERDALIMP'],
                    'QTBRUTASE'       => $qtBruta,
                    'QTUNIDESTSE'     => $qtBruta,
                    'VRPEFATNUTSE'    => '100',
                    'QTCALCNUTRSE'    => $qtCalcNutr,
                    'QTBRUTASEUNR'    => $qtBruta,
                    'HRTEMPPREPSE'    => '00000',
                    'IDPRODBASESE'    => 'N',
                    'IDQTDEFIXSE'     => 'N',
                    'IDUTCOMPENTDIRS' => 'N',
                    'QTCOMPLPRODSERV' => '0',
                    'IDTPREQPRODSERV' => 'P',
                    'CDAPRERECE'      => null,
                    'QTLIMSEGSERV'    => null,
                    'VRPERCDEGELO'    => 0
                );
            break;
            case 'recefili':
                $dadosReceitaInserir = array(
                    'NRORG'           => $produto['NRORG'],
                    '__is_new'        => true,
                    'CDFILAUXPRAT'    => $produto['CDFILAUXPRAT'],
                    'CDPRATO'         => $produto['CDPRATO'],
                    'CDFILIAL'        => $produto['CDFILIAL'],
                    'CDPRODUTO'       => $produto['CDPRODUTO'],
                    'SGUNIDADE'       => $produto['SGUNIDADEPROD'],
                    'QTPRODRECLOC'    => $produto['QUANTIDADE'],
                    'VRPEFATCOCLO'    => $produto['GANHOCOC'],
                    'VRPEFATCORLO'    => $produto['PERDALIMP'],
                    'QTBRUTALO'       => $qtBruta,
                    'QTUNIDESTLO'     => $qtBruta,
                    'VRPEFATNUTLO'    => '100',
                    'QTCALCNUTRLO'    => $qtCalcNutr,
                    'QTBRUTALOUNR'    => $qtBruta,
                    'HRTEMPPREPLO'    => '00000',
                    'IDPRODBASELO'    => 'N',
                    'IDQTDEFIXLO'     => 'N',
                    'IDUTCOMPENTDIRF' => 'N',
                    'QTCOMPLPRODFILI' => '0',
                    'IDTPREQPRODFILI' => 'P',
                    'CDAPRERECE'      => null,
                    'QTLIMSEGFILI'    => null,
                    'VRPERCDEGELO'    => 0
                );
                break;
            case 'receregiao':
                $dadosReceitaInserir = array(
                    'NRORG'             => $produto['NRORG'],
                    '__is_new'          => true,
                    'CDFILAUXPRAT'      => $produto['CDFILAUXPRAT'],
                    'CDPRATO'           => $produto['CDPRATO'],
                    'CDPRODUTO'         => $produto['CDPRODUTO'],
                    'SGUNIDADE'         => $produto['SGUNIDADEPROD'],
                    'QTPRODRECREGIAO'   => $produto['QUANTIDADE'],
                    'VRPEFATCOCREGIAO'  => $produto['GANHOCOC'],
                    'VRPEFATCORREGIAO'  => $produto['PERDALIMP'],
                    'QTBRUTAREGIAOUNR'  => $produto['QTBRUTA'],
                    'IDPRODBASEREGIAO'  => 'N',
                    'IDQTDEFIXREGIAO'   => 'N',
                    'NRRECEREGIAO'      => $produto['CODE'],
                    'CDREGIAO'          => $produto['CDREGIAO'],
                    'changed'           => true,
                    'NRPADRAOQUALIDADE' => $produto['NRPADRAOQUALIDADE']
                );
            break;
            case 'recepadquali':
                $dadosReceitaInserir = array(
                    'NRORG'             => $produto['NRORG'],
                    '__is_new'          => true,
                    'CDFILAUXPRAT'      => $produto['CDFILAUXPRAT'],
                    'CDPRATO'           => $produto['CDPRATO'],
                    'CDPRODUTO'         => $produto['CDPRODUTO'],
                    'SGUNIDADE'         => $produto['SGUNIDADEPROD'],
                    'QTPRODRECPADQ'     => $produto['QUANTIDADE'],
                    'VRPEFATCOCPADQ'    => $produto['GANHOCOC'],
                    'VRPEFATCORPADQ'    => $produto['PERDALIMP'],
                    'QTBRUTAPADQUNR'    => $produto['QTBRUTA'],
                    'IDPRODBASEPR'      => 'N',
                    'NRRECEPADQUALI'    => $produto['CODE'],
                    'NRPADRAOQUALIDADE' => $produto['NRPADRAOQUALIDADE'],
                    'IDQTDEFIXPADQ'     => 'N'
                );
            break;
            case 'recepratcardtrab':
                $dadosReceitaInserir = array(
                    'NRORG'              => $produto['NRORG'],
                    '__is_new'           => true,
                    'CDFILAUXPRAT'       => $produto['CDFILAUXPRAT'],
                    'CDPRATO'            => $produto['CDPRATO'],
                    'CDPRODUTO'          => $produto['CDPRODUTO'],
                    'SGUNIDADE'          => $produto['SGUNIDADEPROD'],
                    'QTPRODRECCARDTRAB'  => $produto['QUANTIDADE'],
                    'VRPEFATCOCCARDTRAB' => $produto['GANHOCOC'],
                    'VRPEFATCORCARDTRAB' => $produto['PERDALIMP'],
                    'QTBRUTACARDTRABUNR' => $produto['QTBRUTA'],
                    'IDPRODBASECARDTRAB' => 'N',
                    'NRRECEPRATCARDTRAB' => $produto['CODE'],
                    'NRCARDAPIOTRAB'     => $produto['NRCARDAPIOTRAB'],
                    'IDQTDEFIXCARDTRAB'  => 'N',
                    'IDINCLUIDO' => 'N'
                );
            break;
                
        }

        $requestInsertReceitaPrato = new DTO\Request\Row(
            $dadosReceitaInserir, '', '', ''
        );
        
        $dadosReceitaInserir = $this->crudService->getRowsToSave(
            $requestInsertReceitaPrato, $dataSourceDestino
        );
        
        $this->crudService->save($dataSourceDestino, $dadosReceitaInserir);
    }
    
    public function insereDadosPrato($dados, $dataSourceDestino){
        
        switch ($dataSourceDestino) {
            case 'pratpadr':
                $dadosPratInserir = array(
                    'NRORG'          => $dados['NRORG'],
                    '__is_new'       => true,
                    'CDFILAUXPRAT'   => $dados['CDFILAUXPRAT'],
                    'CDPRATO'        => $dados['CDPRATO'],
                    'NRCORPRIPRAT'   => $dados['COR'],
                    'NRCORSEQPRAT'   => $dados['COR'],
                    'NRCORAUXPRAT'   => $dados['COR'],
                    'QTPADRAOPRAT'   => $dados['QUANTIDADE'],
                    'QTCONTAIPRAT'   => '0',
                    'HRVALCONPRAT'   => '00000',
                    'NMFANTASIAPR'   => null,
                    'QTCARBOPRPAD'   => '0',
                    'QTLIPIDPRPAD'   => null,
                    'QTPROTEPRPAD'   => null,
                    'QTCALORPRPAD'   => null,
                    'QTALCOOPRPAD'   => null,
                    'VRPEMINPADR'    => null,
                    'QTAMOSTRPADR'   => null,
                    'CDPRODPRODUCAO' => null,
                    'QTLIMSEGPADR'   => '0',
                    'IDPRODCHILL'    => null,
                    'IDTPPRODCHILL'  => 'NENHUM',
                    'IDFINALPADR'    => 'M'
                );
            break;
            case 'pratfili':
                $dadosPratInserir = array(
                    'NRORG'          => $dados['NRORG'],
                    '__is_new'       => true,
                    'CDFILAUXPRAT'   => $dados['CDFILAUXPRAT'],
                    'CDPRATO'        => $dados['CDPRATO'],
                    'CDFILIAL'       => $dados['CDFILIAL'],
                    'NRCORPRIFILI'   => $dados['COR'],
                    'NRCORSEQFILI'   => $dados['COR'],
                    'NRCORAUXFILI'   => $dados['COR'],
                    'QTPADRAOFILI'   => $dados['QUANTIDADE'],
                    'QTCONTAIFILI'   => '0',
                    'HRVALCONFILI'   => '00000',
                    'NMFANTASIAPF'   => null,
                    'QTCARBOPRFIL'   => '0',
                    'QTLIPIDPRFIL'   => null,
                    'QTPROTEPRFIL'   => null,
                    'QTCALORPRFIL'   => null,
                    'QTALCOOPRFIL'   => null,
                    'VRPEMINFILI'    => null,
                    'QTAMOSTRFILI'   => null,
                    'CDPRODPRODUCAO' => null,
                    'QTLIMSEGFILI'   => '0',
                    'IDPRODCHILL'    => null,
                    'IDTPPRODCHILL'  => 'NENHUM',
                    'IDFINALFILI'    => 'M'
                );
            break;
            case 'pratserv':
                $dadosPratInserir = array(
                    'NRORG'          => $dados['NRORG'],
                    '__is_new'       => true,
                    'CDFILAUXPRAT'   => $dados['CDFILAUXPRAT'],
                    'CDPRATO'        => $dados['CDPRATO'],
                    'CDFILIAL'       => $dados['CDFILIAL'],
                    'CDSERVFILI'     => $dados['CDSERVFILI'],
                    'NRCORPRISERV'   => $dados['COR'],
                    'NRCORSEQSERV'   => $dados['COR'],
                    'NRCORAUXSERV'   => $dados['COR'],
                    'QTPADRAOSERV'   => $dados['QUANTIDADE'],
                    'QTCONTAISERV'   => '0',
                    'HRVALCONSERV'   => '00000',
                    'NMFANTASIASE'   => null,
                    'QTCARBOPRSER'   => '0',
                    'QTLIPIDPRSER'   => null,
                    'QTPROTEPRSER'   => null,
                    'QTCALORPRSER'   => null,
                    'QTALCOOPRSER'   => null,
                    'VRPEMINSERV'    => null,
                    'QTAMOSTRSERV'   => null,
                    'CDPRODPRODUCAO' => null,
                    'QTLIMSEGSERV'   => '0',
                    'IDPRODCHILL'    => null,
                    'IDTPPRODCHILL'  => 'NENHUM',
                    'IDFINALSERV'    => 'M'
                );
            break;
            case 'pratregiao':
                $dadosPratInserir = array(
                    'NRORG'            => $dados['NRORG'],
                    '__is_new'         => true,
                    'CDFILAUXPRAT'     => $dados['CDFILAUXPRAT'],
                    'CDPRATO'          => $dados['CDPRATO'],
                    'NRPRATREGIAO'     => $dados['CODE'],
                    'NRPADRAOQUALIDADE'=> $dados['NRPADRAOQUALIDADE'],
                    'CDREGIAO'         => $dados['CDREGIAO'],
                    'NRCORPRIPRAT'     => $dados['COR'],
                    'QTPADRAOPRAT'     => $dados['QUANTIDADE']
                );
            break;
            case 'pratpadquali':
                $dadosPratInserir = array(
                    'NRORG'             => $dados['NRORG'],
                    '__is_new'          => true,
                    'CDFILAUXPRAT'      => $dados['CDFILAUXPRAT'],
                    'CDPRATO'           => $dados['CDPRATO'],
                    'NRPRATPADQUALI'    => $dados['CODE'],
                    'NRPADRAOQUALIDADE' => $dados['NRPADRAOQUALIDADE'],
                    'NRCORPRIPADQ'      => $dados['COR'],
                    'QTPADRAOPADQ'      => $dados['QUANTIDADE']
                );
            break;
        }

        $requestInsertDadosPrato = new DTO\Request\Row(
            $dadosPratInserir, '', '', ''
        );
        
        $dadosPratInserir = $this->crudService->getRowsToSave(
            $requestInsertDadosPrato, $dataSourceDestino
        );

        $this->crudService->save($dataSourceDestino, $dadosPratInserir);
    
    }
    
    public function receitaPorTipo(DTO\Request\Filter $request, DTO\Response $response){
        
        $filtros = $request->getParameters()['filter'];
        $tipoReceita =0;
        foreach ($filtros as $filtro) {
            if($filtro['name'] === 'TIPORECE'){
                $tipoReceita = $filtro['value'];
            }
        }
        switch ($tipoReceita) {
             case 'R':
                $dataSourceName = 'receitaRegiao';
            break;
            case 'Q':
                $dataSourceName = 'receitaPadQua';
            break;
            case 'P':
                $dataSourceName = 'receitaPadrao';
            break;
            case 'S':
                $dataSourceName = 'receitaServico';
            break;
            case 'F':
                $dataSourceName = 'receitaLocal';
            break;
            case 'C':
                $dataSourceName = 'receitaCardProp';
            break;
        }
        
        $this->dataSourceName = $dataSourceName;
        // $this->parameterBagColumns = array('NRORG', 'CDFILIAL');

        $this->find($request, $response);
    }

}
