<?php

namespace Teknisa\TCO\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\FilterCriteria;

class Tco01700TipoPreparo extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    protected $environment;
    protected $entityManager;
    protected $dataSourceManager;
    protected $novoCodigo;
    protected $tco01700tipopreparoservice;

    public function __construct($crudService, $parameterBag, $environment, $entityManager, $dataSourceManager, $novoCodigo, $tco01700tipopreparoservice) {
        $this->crudService                = $crudService;
        $this->environment                = $environment;
        $this->entityManager              = $entityManager;
        $this->dataSourceManager          = $dataSourceManager;
        $this->novoCodigo                 = $novoCodigo;
        $this->tco01700tipopreparoservice = $tco01700tipopreparoservice;
    }
    
    public function salvarTipoPreparo(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        if($row['__is_new']){
            $row['NRTIPOPREPAROTCO'] = $this->novoCodigo->getCodeByTableName("tipopreparotco", $this->environment->getNrOrgTrab());
        }
        $rows = $this->crudService->getRowsToSave($request, "tipopreparotco");
        $this->crudService->save("tipopreparotco", $rows);
        $response->addDataSet(new DataSet ('tipopreparotco', $rows));
    }
    
    public function deleteTipoPreparo(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $ocorrenciasTipoPreparo = $this->tco01700tipopreparoservice->retornaTipoPreparoVinculados($row);
        
        if(sizeof($ocorrenciasTipoPreparo) > 0) {
            $response->addDataSet(new DataSet ('TIPOPREPAROUTILIZADO', $ocorrenciasTipoPreparo));
        } else {
            
            $rows = $this->crudService->getRowsToDelete($request, 'tipopreparotco');
            $dataSet = new DataSet("tipopreparotco", $rows);
            $this->crudService->delete($response, $dataSet);
            
            $response->addDataSet(new DataSet ('tipopreparotco', $rows));
            
        }
    }
    
    public function vinculaTipoPreparoPrato(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $rowsPratos = $this->constroiRowsPratosTipoPrepato($row);
        
        $dataSet = new DataSet("prato", $rowsPratos);
        $newRequest = new DTO\Request\DataSet($dataSet, "", "", "");
        $rows = $this->crudService->getRowsToSave($newRequest, "prato");
        
        $this->crudService->save("prato", $rows);
        $response->addDataSet(new DataSet ('pratosVinculados', $rows));
    }
    
    public function desvinculaTipoPreparoPrato(DTO\Request $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        
        $row = array();
        $row['NRTIPOPREPAROTCO'] = null;
        $row['PRATOSSELECIONADOS'] = $rows[0];
        
        $rowsPratos = $this->constroiRowsPratosTipoPrepato($row);
        
        $dataSet = new DataSet("prato", $rowsPratos);
        $newRequest = new DTO\Request\DataSet($dataSet, "", "", "");
        $rowsToSave = $this->crudService->getRowsToSave($newRequest, "prato");
        
        $this->crudService->save("prato", $rowsToSave);
        $response->addDataSet(new DataSet ('pratosDesvinculados', $rowsToSave));
    }
    
    private function constroiRowsPratosTipoPrepato($row) {
        
        $pratosVinculados = array();
        
        foreach($row["PRATOSSELECIONADOS"] as $prato){
            $prato['NRTIPOPREPAROTCO'] = $row['NRTIPOPREPAROTCO'];
            $prato['changed'] = true;
            $prato['__is_new'] = false;
            array_push($pratosVinculados, $prato);
        }
        
        return $pratosVinculados;
        
    }
    
}